aboutsummaryrefslogtreecommitdiff
path: root/desktop/src/onionshare
diff options
context:
space:
mode:
authorMiguel Jacq <mig@mig5.net>2021-11-08 16:31:05 +1100
committerMiguel Jacq <mig@mig5.net>2021-11-08 16:31:05 +1100
commit627c185fcb3c369f291b285910421d9cdcbf2f86 (patch)
tree35f2e3883466b684bbeb0b5b072c86e606ceabff /desktop/src/onionshare
parent1b259a208d29c2c8e8eae1d2f1fe28e59eed769b (diff)
downloadonionshare-627c185fcb3c369f291b285910421d9cdcbf2f86.tar.gz
onionshare-627c185fcb3c369f291b285910421d9cdcbf2f86.zip
Support sending a custom Content-Security-Policy header in Website mode
Diffstat (limited to 'desktop/src/onionshare')
-rw-r--r--desktop/src/onionshare/resources/locale/en.json5
-rw-r--r--desktop/src/onionshare/tab/mode/website_mode/__init__.py54
2 files changed, 56 insertions, 3 deletions
diff --git a/desktop/src/onionshare/resources/locale/en.json b/desktop/src/onionshare/resources/locale/en.json
index 03694947..437a3eda 100644
--- a/desktop/src/onionshare/resources/locale/en.json
+++ b/desktop/src/onionshare/resources/locale/en.json
@@ -196,7 +196,8 @@
"mode_settings_receive_disable_text_checkbox": "Disable submitting text",
"mode_settings_receive_disable_files_checkbox": "Disable uploading files",
"mode_settings_receive_webhook_url_checkbox": "Use notification webhook",
- "mode_settings_website_disable_csp_checkbox": "Don't send Content Security Policy header (allows your website to use third-party resources)",
+ "mode_settings_website_disable_csp_checkbox": "Don't send default Content Security Policy header (allows your website to use third-party resources)",
+ "mode_settings_website_custom_csp_checkbox": "Send a Custom Content Security Policy header",
"gui_all_modes_transfer_finished_range": "Transferred {} - {}",
"gui_all_modes_transfer_finished": "Transferred {}",
"gui_all_modes_transfer_canceled_range": "Canceled {} - {}",
@@ -216,4 +217,4 @@
"error_port_not_available": "OnionShare port not available",
"history_receive_read_message_button": "Read Message",
"error_tor_protocol_error": "There was an error with Tor: {}"
-} \ No newline at end of file
+}
diff --git a/desktop/src/onionshare/tab/mode/website_mode/__init__.py b/desktop/src/onionshare/tab/mode/website_mode/__init__.py
index a50d15b9..6d1df88c 100644
--- a/desktop/src/onionshare/tab/mode/website_mode/__init__.py
+++ b/desktop/src/onionshare/tab/mode/website_mode/__init__.py
@@ -49,6 +49,7 @@ class WebsiteMode(Mode):
self.web = Web(self.common, True, self.settings, "website")
# Settings
+ # Disable CSP option
self.disable_csp_checkbox = QtWidgets.QCheckBox()
self.disable_csp_checkbox.clicked.connect(self.disable_csp_checkbox_clicked)
self.disable_csp_checkbox.setText(
@@ -63,6 +64,26 @@ class WebsiteMode(Mode):
self.disable_csp_checkbox
)
+ # Custom CSP option
+ self.custom_csp_checkbox = QtWidgets.QCheckBox()
+ self.custom_csp_checkbox.clicked.connect(self.custom_csp_checkbox_clicked)
+ self.custom_csp_checkbox.setText(strings._("mode_settings_website_custom_csp_checkbox"))
+ if self.settings.get("website", "custom_csp") and not self.settings.get("website", "disable_csp"):
+ self.custom_csp_checkbox.setCheckState(QtCore.Qt.Checked)
+ else:
+ self.custom_csp_checkbox.setCheckState(QtCore.Qt.Unchecked)
+ self.custom_csp = QtWidgets.QLineEdit()
+ self.custom_csp.setPlaceholderText(
+ "default-src 'self'; frame-ancestors 'none'; form-action 'self'; base-uri 'self'; img-src 'self' data:;"
+ )
+ self.custom_csp.editingFinished.connect(self.custom_csp_editing_finished)
+
+ custom_csp_layout = QtWidgets.QHBoxLayout()
+ custom_csp_layout.setContentsMargins(0, 0, 0, 0)
+ custom_csp_layout.addWidget(self.custom_csp_checkbox)
+ custom_csp_layout.addWidget(self.custom_csp)
+ self.mode_settings_widget.mode_specific_layout.addLayout(custom_csp_layout)
+
# File selection
self.file_selection = FileSelection(
self.common,
@@ -183,11 +204,42 @@ class WebsiteMode(Mode):
def disable_csp_checkbox_clicked(self):
"""
Save disable CSP setting to the tab settings
"""
self.settings.set(
"website", "disable_csp", self.disable_csp_checkbox.isChecked()
)
+ if self.disable_csp_checkbox.isChecked():
+ self.custom_csp_checkbox.setCheckState(QtCore.Qt.Unchecked)
+ self.custom_csp_checkbox.setEnabled(False)
+ else:
+ self.custom_csp_checkbox.setEnabled(True)
+
+ def custom_csp_checkbox_clicked(self):
+ """
+ Uncheck 'disable CSP' setting if custom CSP is used.
+ """
+ if self.custom_csp_checkbox.isChecked():
+ self.disable_csp_checkbox.setCheckState(QtCore.Qt.Unchecked)
+ self.disable_csp_checkbox.setEnabled(False)
+ self.settings.set(
+ "website", "custom_csp", self.custom_csp
+ )
+ else:
+ self.disable_csp_checkbox.setEnabled(True)
+ self.custom_csp.setText("")
+ self.settings.set(
+ "website", "custom_csp", None
+ )
+
+ def custom_csp_editing_finished(self):
+ if self.custom_csp.text().strip() == "":
+ self.custom_csp.setText("")
+ self.settings.set("website", "custom_csp", None)
+ else:
+ custom_csp = self.custom_csp.text()
+ self.settings.set("website", "custom_csp", custom_csp)
def get_stop_server_autostop_timer_text(self):
"""
@@ -183,11 +204,42 @@ class WebsiteMode(Mode):
def disable_csp_checkbox_clicked(self):
"""
- Save disable CSP setting to the tab settings
+ Save disable CSP setting to the tab settings. Uncheck 'custom CSP'
+ setting if disabling CSP altogether.
"""
self.settings.set(